@@ -1,4 +1,6 @@
 """sort extension."""
+from typing import List, Optional
+
 import attr
 from fastapi import FastAPI
 
@@ -15,6 +17,11 @@ class SortExtension(ApiExtension):
     https://github.com/radiantearth/stac-api-spec/blob/master/item-search/README.md#sort
     """
 
+    conformance_classes: List[str] = attr.ib(
+        factory=lambda: ["https://api.stacspec.org/v1.0.0-beta.3/item-search/#sort"]
+    )
+    schema_href: Optional[str] = attr.ib(default=None)
+
     def register(self, app: FastAPI) -> None:
         """Register the extension with a FastAPI application.
 
